@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,26 +16,15 @@
  */
 package org.apache.qpid.jms;
 
-import javax.jms.JMSException;
+import jakarta.jms.JMSException;
 
 import org.apache.qpid.jms.meta.JmsConsumerId;
 
 /**
  * Implementation of a TopicSubscriber that is Durable
  */
-public class JmsDurableTopicSubscriber extends JmsTopicSubscriber {
+public class JmsDurableTopicSubscriber extends JmsTopicSubscriber implements AutoCloseable {
 
-    /**
-     * Creates a durable TopicSubscriber
-     *
-     * @param id
-     * @param s
-     * @param destination
-     * @param name
-     * @param noLocal
-     * @param selector
-     * @throws JMSException
-     */
     public JmsDurableTopicSubscriber(JmsConsumerId id, JmsSession s, JmsDestination destination, String name, boolean noLocal, String selector) throws JMSException {
         super(id, s, destination, name, noLocal, selector);
     }
