@@ -16,7 +16,6 @@
  */
 package org.apache.qpid.jms.provider.amqp;
 
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
@@ -24,23 +23,24 @@ import java.util.LinkedHashMap;
 import java.util.Map;
 import java.util.concurrent.ScheduledFuture;
 
-import javax.jms.IllegalStateException;
-import javax.jms.JMSException;
-
-import org.apache.qpid.jms.JmsSendTimedOutException;
 import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
 import org.apache.qpid.jms.meta.JmsConnectionInfo;
 import org.apache.qpid.jms.meta.JmsProducerInfo;
 import org.apache.qpid.jms.provider.AsyncResult;
+import org.apache.qpid.jms.provider.ProviderException;
 import org.apache.qpid.jms.provider.amqp.message.AmqpReadableBuffer;
-import org.apache.qpid.jms.util.IOExceptionSupport;
-import org.apache.qpid.proton.amqp.messaging.Accepted;
+import org.apache.qpid.jms.provider.exceptions.ProviderDeliveryModifiedException;
+import org.apache.qpid.jms.provider.exceptions.ProviderDeliveryReleasedException;
+import org.apache.qpid.jms.provider.exceptions.ProviderExceptionSupport;
+import org.apache.qpid.jms.provider.exceptions.ProviderIllegalStateException;
+import org.apache.qpid.jms.provider.exceptions.ProviderSendTimedOutException;
+import org.apache.qpid.jms.provider.exceptions.ProviderUnsupportedOperationException;
+import org.apache.qpid.jms.tracing.JmsTracer;
 import org.apache.qpid.proton.amqp.messaging.Modified;
-import org.apache.qpid.proton.amqp.messaging.Outcome;
 import org.apache.qpid.proton.amqp.messaging.Rejected;
-import org.apache.qpid.proton.amqp.messaging.Released;
 import org.apache.qpid.proton.amqp.transaction.TransactionalState;
 import org.apache.qpid.proton.amqp.transport.DeliveryState;
+import org.apache.qpid.proton.amqp.transport.DeliveryState.DeliveryStateType;
 import org.apache.qpid.proton.amqp.transport.ErrorCondition;
 import org.apache.qpid.proton.amqp.transport.SenderSettleMode;
 import org.apache.qpid.proton.engine.Delivery;
@@ -64,14 +64,15 @@ public class AmqpFixedProducer extends AmqpProducer {
     private final Map<Object, InFlightSend> sent = new LinkedHashMap<Object, InFlightSend>();
     private final Map<Object, InFlightSend> blocked = new LinkedHashMap<Object, InFlightSend>();
 
-    private AsyncResult sendCompletionWatcher;
-
     private final AmqpConnection connection;
+    private final JmsTracer tracer;
 
     public AmqpFixedProducer(AmqpSession session, JmsProducerInfo info, Sender sender) {
         super(session, info, sender);
 
         connection = session.getConnection();
+        tracer = connection.getResourceInfo().getTracer();
+
         delayedDeliverySupported = connection.getProperties().isDelayedDeliverySupported();
     }
 
@@ -87,38 +88,35 @@ public class AmqpFixedProducer extends AmqpProducer {
     }
 
     @Override
-    public void send(JmsOutboundMessageDispatch envelope, AsyncResult request) throws IOException, JMSException {
-        if (isClosed()) {
-            request.onFailure(new IllegalStateException("The MessageProducer is closed"));
-        }
+    public void send(JmsOutboundMessageDispatch envelope, AsyncResult request) throws ProviderException {
+        if (!isClosed()) {
+            final InFlightSend send = new InFlightSend(envelope, request);
 
-        if (!delayedDeliverySupported && envelope.getMessage().getFacade().isDeliveryTimeTransmitted()) {
-            // Don't allow sends with delay if the remote has not said it can handle them
-            request.onFailure(new JMSException("Remote does not support delayed message delivery"));
-        } else if (getEndpoint().getCredit() <= 0) {
-            LOG.trace("Holding Message send until credit is available.");
+            if (!delayedDeliverySupported && envelope.getMessage().getFacade().isDeliveryTimeTransmitted()) {
+                // Don't allow sends with delay if the remote has not said it can handle them
+                send.onFailure(new ProviderUnsupportedOperationException("Remote does not support delayed message delivery"));
+            } else if (session.isTransactionInDoubt()) {
+                // If the transaction has failed due to remote termination etc then we just indicate
+                // the send has succeeded until the a new transaction is started.
+                send.onSuccess();
+            } else if (getEndpoint().getCredit() <= 0) {
+                LOG.trace("Holding Message send until credit is available.");
 
-            InFlightSend send = new InFlightSend(envelope, request);
+                if (getSendTimeout() > JmsConnectionInfo.INFINITE) {
+                    send.requestTimeout = getParent().getProvider().scheduleRequestTimeout(send, getSendTimeout(), send);
+                }
 
-            if (getSendTimeout() > JmsConnectionInfo.INFINITE) {
-                send.requestTimeout = getParent().getProvider().scheduleRequestTimeout(send, getSendTimeout(), send);
+                blocked.put(envelope.getMessageId(), send);
+                getParent().getProvider().pumpToProtonTransport(request);
+            } else {
+                doSend(envelope, send);
             }
-
-            blocked.put(envelope.getMessageId(), send);
-            getParent().getProvider().pumpToProtonTransport(request);
         } else {
-            // If the transaction has failed due to remote termination etc then we just indicate
-            // the send has succeeded until the a new transaction is started.
-            if (session.isTransacted() && session.isTransactionFailed()) {
-                request.onSuccess();
-                return;
-            }
-
-            doSend(envelope, new InFlightSend(envelope, request));
+            request.onFailure(new ProviderIllegalStateException("The MessageProducer is closed"));
         }
     }
 
-    private void doSend(JmsOutboundMessageDispatch envelope, InFlightSend send) throws IOException, JMSException {
+    private void doSend(JmsOutboundMessageDispatch envelope, InFlightSend send) throws ProviderException {
         LOG.trace("Producer sending message: {}", envelope);
 
         boolean presettle = envelope.isPresettle() || isPresettle();
@@ -171,12 +169,16 @@ public class AmqpFixedProducer extends AmqpProducer {
                 send.getOriginalRequest().onSuccess();
             }
 
-            provider.getTransport().flush();
+            try {
+                provider.getTransport().flush();
+            } catch (Throwable ex) {
+                throw ProviderExceptionSupport.createOrPassthroughFatal(ex);
+            }
         }
     }
 
     @Override
-    public void processFlowUpdates(AmqpProvider provider) throws IOException {
+    public void processFlowUpdates(AmqpProvider provider) throws ProviderException {
         if (!blocked.isEmpty() && getEndpoint().getCredit() > 0) {
             Iterator<InFlightSend> blockedSends = blocked.values().iterator();
             while (getEndpoint().getCredit() > 0 && blockedSends.hasNext()) {
@@ -185,14 +187,12 @@ public class AmqpFixedProducer extends AmqpProducer {
                 try {
                     // If the transaction has failed due to remote termination etc then we just indicate
                     // the send has succeeded until the a new transaction is started.
-                    if (session.isTransacted() && session.isTransactionFailed()) {
+                    if (session.isTransacted() && session.isTransactionInDoubt()) {
                         held.onSuccess();
                         return;
                     }
 
                     doSend(held.getEnvelope(), held);
-                } catch (JMSException e) {
-                    throw IOExceptionSupport.create(e);
                 } finally {
                     blockedSends.remove();
                 }
@@ -208,59 +208,64 @@ public class AmqpFixedProducer extends AmqpProducer {
     }
 
     @Override
-    public void processDeliveryUpdates(AmqpProvider provider, Delivery delivery) throws IOException {
+    public void processDeliveryUpdates(AmqpProvider provider, Delivery delivery) throws ProviderException {
         DeliveryState state = delivery.getRemoteState();
         if (state != null) {
-
             InFlightSend send = (InFlightSend) delivery.getContext();
 
-            if (state instanceof Accepted) {
+            if (state.getType() == DeliveryStateType.Accepted) {
                 LOG.trace("Outcome of delivery was accepted: {}", delivery);
                 send.onSuccess();
-                super.processDeliveryUpdates(provider, delivery);
-                return;
-            }
-
-            Exception deliveryError = null;
-            Outcome outcome = null;
-
-            if (state instanceof TransactionalState) {
-                LOG.trace("State of delivery is Transactional, retrieving outcome: {}", state);
-                outcome = ((TransactionalState) state).getOutcome();
-            } else if (state instanceof Outcome) {
-                outcome = (Outcome) state;
             } else {
-                LOG.warn("Message send updated with unsupported state: {}", state);
-                outcome = null;
-            }
-
-            if (outcome instanceof Accepted) {
-                LOG.trace("Outcome of delivery was accepted: {}", delivery);
-                send.onSuccess();
-            } else if (outcome instanceof Rejected) {
-                LOG.trace("Outcome of delivery was rejected: {}", delivery);
-                ErrorCondition remoteError = ((Rejected) outcome).getError();
-                if (remoteError == null) {
-                    remoteError = getEndpoint().getRemoteCondition();
-                }
-
-                deliveryError = AmqpSupport.convertToException(getParent().getProvider(), getEndpoint(), remoteError);
-            } else if (outcome instanceof Released) {
-                LOG.trace("Outcome of delivery was released: {}", delivery);
-                deliveryError = new JMSException("Delivery failed: released by receiver");
-            } else if (outcome instanceof Modified) {
-                LOG.trace("Outcome of delivery was modified: {}", delivery);
-                deliveryError = new JMSException("Delivery failed: failure at remote");
-            }
-
-            if (deliveryError != null) {
-                send.onFailure(deliveryError);
+                applyDeliveryStateUpdate(send, delivery, state);
             }
         }
 
         super.processDeliveryUpdates(provider, delivery);
     }
 
+    private void applyDeliveryStateUpdate(InFlightSend send, Delivery delivery, DeliveryState state) {
+        ProviderException deliveryError = null;
+        if (state == null) {
+            return;
+        }
+
+        switch (state.getType()) {
+            case Transactional:
+                LOG.trace("State of delivery is Transactional, retrieving outcome: {}", state);
+                applyDeliveryStateUpdate(send, delivery, (DeliveryState) ((TransactionalState) state).getOutcome());
+                break;
+            case Accepted:
+                LOG.trace("Outcome of delivery was accepted: {}", delivery);
+                send.onSuccess();
+                break;
+            case Rejected:
+                LOG.trace("Outcome of delivery was rejected: {}", delivery);
+                ErrorCondition remoteError = ((Rejected) state).getError();
+                if (remoteError == null) {
+                    remoteError = getEndpoint().getRemoteCondition();
+                }
+
+                deliveryError = AmqpSupport.convertToNonFatalException(getParent().getProvider(), getEndpoint(), remoteError);
+                break;
+            case Released:
+                LOG.trace("Outcome of delivery was released: {}", delivery);
+                deliveryError = new ProviderDeliveryReleasedException("Delivery failed: released by receiver");
+                break;
+            case Modified:
+                LOG.trace("Outcome of delivery was modified: {}", delivery);
+                Modified modified = (Modified) state;
+                deliveryError = new ProviderDeliveryModifiedException("Delivery failed: failure at remote", modified);
+                break;
+            default:
+                LOG.warn("Message send updated with unsupported state: {}", state);
+        }
+
+        if (deliveryError != null) {
+            send.onFailure(deliveryError);
+        }
+    }
+
     public AmqpSession getSession() {
         return session;
     }
@@ -285,10 +290,15 @@ public class AmqpFixedProducer extends AmqpProducer {
     }
 
     @Override
-    public void handleResourceClosure(AmqpProvider provider, Throwable error) {
+    public void handleResourceClosure(AmqpProvider provider, ProviderException error) {
         if (error == null) {
-            // TODO: create/use a more specific/appropriate exception type?
-            error = new JMSException("Producer closed remotely before message transfer result was notified");
+            // In case close was expected but remote did provide error context we propagate that to the outstanding
+            // sends that will be failed in order to provide more specific context to the send failure.
+            if (getEndpoint().getRemoteCondition() != null) {
+                error = AmqpSupport.convertToNonFatalException(provider, getEndpoint(), getEndpoint().getRemoteCondition());
+            } else {
+                error = new ProviderException("Producer closed remotely before message transfer result was notified");
+            }
         }
 
         Collection<InFlightSend> inflightSends = new ArrayList<InFlightSend>(sent.values());
@@ -312,7 +322,7 @@ public class AmqpFixedProducer extends AmqpProducer {
 
     //----- Class used to manage held sends ----------------------------------//
 
-    private class InFlightSend implements AsyncResult, AmqpExceptionBuilder {
+    private final class InFlightSend implements AsyncResult, AmqpExceptionBuilder {
 
         private final JmsOutboundMessageDispatch envelope;
         private final AsyncResult request;
@@ -326,16 +336,16 @@ public class AmqpFixedProducer extends AmqpProducer {
         }
 
         @Override
-        public void onFailure(Throwable cause) {
+        public void onFailure(ProviderException cause) {
             handleSendCompletion(false);
 
             if (request.isComplete()) {
                 // Asynchronous sends can still be awaiting a completion in which case we
                 // send to them otherwise send to the listener to be reported.
                 if (envelope.isCompletionRequired()) {
-                    getParent().getProvider().getProviderListener().onFailedMessageSend(envelope, cause);
+                    getParent().getProvider().getProviderListener().onFailedMessageSend(envelope, ProviderExceptionSupport.createNonFatalOrPassthrough(cause));
                 } else {
-                    getParent().getProvider().fireNonFatalProviderException(IOExceptionSupport.create(cause));
+                    getParent().getProvider().fireNonFatalProviderException(ProviderExceptionSupport.createNonFatalOrPassthrough(cause));
                 }
             } else {
                 request.onFailure(cause);
@@ -387,24 +397,23 @@ public class AmqpFixedProducer extends AmqpProducer {
         private void handleSendCompletion(boolean successful) {
             setRequestTimeout(null);
 
+            // Null delivery means that we never had credit to send so no delivery was created to carry the message.
             if (getDelivery() != null) {
                 sent.remove(envelope.getMessageId());
                 delivery.settle();
-                tagGenerator.returnTag(delivery.getTag());
+                if (successful) {
+                    tagGenerator.returnTag(delivery.getTag());
+                }
+                final DeliveryState remoteState = delivery.getRemoteState();
+                tracer.completeSend(envelope.getMessage().getFacade(), remoteState == null ? null : remoteState.getType().name());
             } else {
                 blocked.remove(envelope.getMessageId());
+                tracer.completeSend(envelope.getMessage().getFacade(), null);
             }
 
             // Put the message back to usable state following send complete
             envelope.getMessage().onSendComplete();
 
-            // Signal the watcher that all pending sends have completed if one is registered
-            // and both the in-flight sends and blocked sends have completed.
-            if (sendCompletionWatcher != null && sent.isEmpty() && blocked.isEmpty()) {
-                sendCompletionWatcher.onSuccess();
-                sendCompletionWatcher = null;
-            }
-
             // Once the pending sends queue is drained and all in-flight sends have been
             // settled we can propagate the close request.
             if (isAwaitingClose() && !isClosed() && blocked.isEmpty() && sent.isEmpty()) {
@@ -413,11 +422,11 @@ public class AmqpFixedProducer extends AmqpProducer {
         }
 
         @Override
-        public Exception createException() {
+        public ProviderException createException() {
             if (delivery == null) {
-                return new JmsSendTimedOutException("Timed out waiting for credit to send Message", envelope.getMessage());
+                return new ProviderSendTimedOutException("Timed out waiting for credit to send Message", envelope.getMessage());
             } else {
-                return new JmsSendTimedOutException("Timed out waiting for disposition of sent Message", envelope.getMessage());
+                return new ProviderSendTimedOutException("Timed out waiting for disposition of sent Message", envelope.getMessage());
             }
         }
     }
