@@ -16,14 +16,15 @@
  */
 package org.apache.qpid.jms.provider.amqp.message;
 
+import java.nio.ByteBuffer;
 import java.util.Map;
 
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.messaging.MessageAnnotations;
+import org.apache.qpid.proton.codec.ReadableBuffer;
 import org.apache.qpid.proton.message.Message;
 
 import io.netty.buffer.ByteBuf;
-import io.netty.buffer.Unpooled;
 
 /**
  * Support class containing constant values and static methods that are
@@ -35,12 +36,12 @@ public final class AmqpMessageSupport {
      * Attribute used to mark the class type of JMS message that a particular message
      * instance represents, used internally by the client.
      */
-    public static final String JMS_MSG_TYPE = "x-opt-jms-msg-type";
+    public static final Symbol JMS_MSG_TYPE = Symbol.valueOf("x-opt-jms-msg-type");
 
     /**
      * Attribute used to mark the Application defined delivery time assigned to the message
      */
-    public static final String JMS_DELIVERY_TIME = "x-opt-delivery-time";
+    public static final Symbol JMS_DELIVERY_TIME = Symbol.valueOf("x-opt-delivery-time");
 
     /**
      * Value mapping for JMS_MSG_TYPE which indicates the message is a generic JMS Message
@@ -85,48 +86,36 @@ public final class AmqpMessageSupport {
     /**
      * Content type used to mark Data sections as containing a serialized java object.
      */
-    public static final String SERIALIZED_JAVA_OBJECT_CONTENT_TYPE = "application/x-java-serialized-object";
+    public static final Symbol SERIALIZED_JAVA_OBJECT_CONTENT_TYPE = Symbol.valueOf("application/x-java-serialized-object");
 
     /**
      * Content type used to mark Data sections as containing arbitrary bytes.
      */
-    public static final String OCTET_STREAM_CONTENT_TYPE = "application/octet-stream";
+    public static final Symbol OCTET_STREAM_CONTENT_TYPE = Symbol.valueOf("application/octet-stream");
 
     // For support of old string destination type annotations
-    public static final String LEGACY_TO_TYPE_MSG_ANNOTATION_SYMBOL_NAME = "x-opt-to-type";
-    public static final String LEGACY_REPLY_TO_TYPE_MSG_ANNOTATION_SYMBOL_NAME = "x-opt-reply-type";
+    public static final Symbol LEGACY_TO_TYPE_MSG_ANNOTATION_SYMBOL = Symbol.valueOf("x-opt-to-type");
+    public static final Symbol LEGACY_REPLY_TO_TYPE_MSG_ANNOTATION_SYMBOL = Symbol.valueOf("x-opt-reply-type");
     public static final String LEGACY_QUEUE_ATTRIBUTE = "queue";
     public static final String LEGACY_TOPIC_ATTRIBUTE = "topic";
     public static final String LEGACY_TEMPORARY_ATTRIBUTE = "temporary";
 
-    /**
-     * Lookup and return the correct Proton Symbol instance based on the given key.
-     *
-     * @param key
-     *        the String value name of the Symbol to locate.
-     *
-     * @return the Symbol value that matches the given key.
-     */
-    public static Symbol getSymbol(String key) {
-        return Symbol.valueOf(key);
-    }
-
     /**
      * Safe way to access message annotations which will check internal structure and
      * either return the annotation if it exists or null if the annotation or any annotations
      * are present.
      *
      * @param key
-     *        the String key to use to lookup an annotation.
+     *        the Symbol key to use to lookup an annotation.
      * @param messageAnnotations
      *        the AMQP message annotations object that is being examined.
      *
      * @return the given annotation value or null if not present in the message.
      */
-    public static Object getMessageAnnotation(String key, MessageAnnotations messageAnnotations) {
+    public static Object getMessageAnnotation(Symbol key, MessageAnnotations messageAnnotations) {
         if (messageAnnotations != null && messageAnnotations.getValue() != null) {
             Map<Symbol, Object> annotations = messageAnnotations.getValue();
-            return annotations.get(AmqpMessageSupport.getSymbol(key));
+            return annotations.get(key);
         }
 
         return null;
@@ -144,13 +133,13 @@ public final class AmqpMessageSupport {
      *
      * @return true if content type matches
      */
-    public static boolean isContentType(String contentType, Symbol messageContentType) {
+    public static boolean isContentType(Symbol contentType, Symbol messageContentType) {
         if (contentType == null) {
             return messageContentType == null;
         } else if (messageContentType == null) {
             return false;
         } else {
-            return contentType.equals(messageContentType.toString());
+            return contentType.equals(messageContentType);
         }
     }
 
@@ -179,7 +168,7 @@ public final class AmqpMessageSupport {
      *
      * @return a buffer containing the wire level representation of the input Message.
      */
-    public static ByteBuf encodeMessage(Message message) {
+    public static ReadableBuffer encodeMessage(Message message) {
         final int BUFFER_SIZE = 4096;
         byte[] encodedMessage = new byte[BUFFER_SIZE];
         int encodedSize = 0;
@@ -192,6 +181,6 @@ public final class AmqpMessageSupport {
             }
         }
 
-        return Unpooled.wrappedBuffer(encodedMessage, 0, encodedSize);
+        return ReadableBuffer.ByteBufferReader.wrap(ByteBuffer.wrap(encodedMessage, 0, encodedSize));
     }
 }
