@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -21,6 +21,7 @@ import java.util.Map;
 
 import org.apache.qpid.jms.provider.Provider;
 import org.apache.qpid.jms.provider.ProviderFactory;
+import org.apache.qpid.jms.provider.ProviderFutureFactory;
 import org.apache.qpid.jms.util.PropertyUtil;
 import org.apache.qpid.jms.util.URISupport;
 import org.apache.qpid.jms.util.URISupport.CompositeData;
@@ -42,13 +43,34 @@ public class FailoverProviderFactory extends ProviderFactory {
 
     @Override
     public Provider createProvider(URI remoteURI) throws Exception {
+        return createProvider(remoteURI, null);
+    }
+
+    @Override
+    public Provider createProvider(URI remoteURI, ProviderFutureFactory futureFactory) throws Exception {
         CompositeData composite = URISupport.parseComposite(remoteURI);
         Map<String, String> options = composite.getParameters();
 
         Map<String, String> filtered = PropertyUtil.filterProperties(options, FAILOVER_OPTION_PREFIX);
         Map<String, String> nested = PropertyUtil.filterProperties(filtered, FAILOVER_NESTED_OPTION_PREFIX_ADDON);
 
-        FailoverProvider provider = new FailoverProvider(composite.getComponents(), nested);
+        Map<String, String> providerOptions = PropertyUtil.filterProperties(options, "provider.");
+        // If we have been given a futures factory to use then we ignore any URI options indicating
+        // what to create and just go with what we are given.
+        if (futureFactory == null) {
+            // Create a configured ProviderFutureFactory for use by the resulting AmqpProvider
+            futureFactory = ProviderFutureFactory.create(providerOptions);
+            if (!providerOptions.isEmpty()) {
+                String msg = ""
+                    + " Not all Provider options could be applied during Failover Provider creation."
+                    + " Check the options are spelled correctly."
+                    + " Unused parameters=[" + providerOptions + "]."
+                    + " This provider instance cannot be started.";
+                throw new IllegalArgumentException(msg);
+            }
+        }
+
+        FailoverProvider provider = new FailoverProvider(composite.getComponents(), nested, futureFactory);
         Map<String, String> unused = PropertyUtil.setProperties(provider, filtered);
         if (!unused.isEmpty()) {
             String msg = ""
