@@ -16,7 +16,7 @@
  */
 package org.apache.qpid.jms.producer;
 
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.concurrent.TimeUnit;
 
