@@ -18,11 +18,11 @@ package org.apache.qpid.jms.producer;
 
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
-import javax.jms.Queue;
-import javax.jms.QueueConnection;
-import javax.jms.QueueSender;
-import javax.jms.QueueSession;
-import javax.jms.Session;
+import jakarta.jms.Queue;
+import jakarta.jms.QueueConnection;
+import jakarta.jms.QueueSender;
+import jakarta.jms.QueueSession;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
 import org.junit.jupiter.api.BeforeEach;
@@ -55,7 +55,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetDeliveryModeFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getDeliveryMode();
         });
     }
@@ -63,7 +63,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetDestinationFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getDestination();
         });
     }
@@ -71,7 +71,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetQueueFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getQueue();
         });
     }
@@ -79,7 +79,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetDisableMessageIDFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getDisableMessageID();
         });
     }
@@ -87,7 +87,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetDisableMessageTimestampFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getDisableMessageTimestamp();
         });
     }
@@ -95,7 +95,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetTimeToLiveFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getTimeToLive();
         });
     }
@@ -103,7 +103,7 @@ public class JmsQueueSenderClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testGetPriorityFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             sender.getPriority();
         });
     }
