@@ -18,12 +18,12 @@ package org.apache.qpid.jms.session;
 
 import static org.junit.jupiter.api.Assertions.assertThrows;
 
-import javax.jms.Session;
-import javax.jms.Topic;
-import javax.jms.TopicConnection;
-import javax.jms.TopicPublisher;
-import javax.jms.TopicSession;
-import javax.jms.TopicSubscriber;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
+import jakarta.jms.TopicConnection;
+import jakarta.jms.TopicPublisher;
+import jakarta.jms.TopicSession;
+import jakarta.jms.TopicSubscriber;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
 import org.junit.jupiter.api.BeforeEach;
@@ -70,7 +70,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreatePublisher() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createPublisher(destination);
         });
     }
@@ -78,7 +78,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreateSubscriber() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createSubscriber(destination);
         });
     }
@@ -86,7 +86,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreateSubscriberWithSelector() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createSubscriber(destination, "color = blue", false);
         });
     }
@@ -94,7 +94,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreateDurableSubscriber() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createDurableSubscriber(destination, "foo");
         });
     }
@@ -102,7 +102,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreateDurableSubscriberWithSelector() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createDurableSubscriber(destination, "foo", "color = blue", false);
         });
     }
@@ -110,7 +110,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testCreateDurableConsumerWithSelector() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             session.createDurableConsumer(destination, "foo", "color = blue", false);
         });
     }
@@ -132,7 +132,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testSubscriberGetTopicFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             subscriber.getTopic();
         });
     }
@@ -140,7 +140,7 @@ public class JmsTopicSessionClosedTest extends JmsConnectionTestSupport {
     @Test
     @Timeout(30)
     public void testPublisherGetTopicFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
+        assertThrows(jakarta.jms.IllegalStateException.class, () -> {
             publisher.getTopic();
         });
     }
